@@ -38,7 +38,7 @@ sub sudoers {
 		# setup alias, so we could easily remove these later by matching lines with 'CHECK_RAID'
 		# also this avoids installing ourselves twice.
 		"# Lines matching CHECK_RAID added by $0 -S on ". scalar localtime,
-		"User_Alias CHECK_RAID=nagios, icinga",
+		"User_Alias CHECK_RAID=nagios, icinga, sensu",
 		"Defaults:CHECK_RAID !requiretty",
 
 		# actual rules from plugins
