@@ -18,7 +18,7 @@ our $debug = 0;
 
 # paths for which()
 our @paths = split /:/, $ENV{'PATH'};
-unshift(@paths, qw(/usr/local/nrpe /usr/local/bin /sbin /usr/sbin /bin /usr/sbin /opt/bin /opt/MegaRAID/MegaCli));
+unshift(@paths, qw(/usr/local/nrpe /usr/local/bin /sbin /usr/sbin /bin /usr/sbin /opt/bin /opt/MegaRAID/MegaCli /usr/StorMan));
 
 # lookup program from list of possible filenames
 # search is performed from $PATH plus additional hardcoded @paths
@@ -51,6 +51,9 @@ sub find_sudo {
 	local $/ = undef;
 	local $_ = <$fh>;
 	close($fh) or die $!;
+	# prefer -n to skip password prompt
+	push(@sudo, '-n') if /-n/;
+	# ..if not supported, add -A as well
 	push(@sudo, '-A') if /-A/;
 
 	return \@sudo;
